import Vue from 'vue';
import Vuex from 'vuex';
import {
	localStorage
} from '@/js_sdk/mp-storage/mp-storage/index.js'
import { getConfig } from '@../../pages/lottery/common/api.js'

//全局风格设置
Vue.use(Vuex);

// 定义一个常量作为存储键名
const STORAGE_KEY = 'APP_CONFIG'

var appStyle = "";
if(localStorage.getItem('appSwiperStyle')){
	var appSwiperStyle = localStorage.getItem('appSwiperStyle');
	if (appSwiperStyle == -1) {
		appStyle = "ablaod";
	}
	if (appSwiperStyle == 0) {
		appStyle = "abload";
	}
	if (appSwiperStyle == 1) {
		appStyle = "aloab";
	}
	if (appSwiperStyle == 2) {
		appStyle = "adload";
	}
	if (appSwiperStyle == null) {
		appStyle = "oblaod";
	}
}

const store = new Vuex.Store({
	state:{
		AppStyle: appStyle,
		// 存储完整的配置信息
		config: {
			icons: [], // 图标列表
			// 其他配置信息...
		}
	},
	mutations:{
		setStyle(state, style) {
			state.AppStyle = style
		},
		// 设置完整配置信息
		SET_CONFIG(state, config) {
			state.config = config
		},
	},
	actions: {
		// 获取配置信息
		async getConfigInfo({ commit }) {
			try {
				// 先从本地存储获取完整配置
				const storageConfig = uni.getStorageSync(STORAGE_KEY)
				if (storageConfig) {
					commit('SET_CONFIG', JSON.parse(storageConfig))
				}
				
				// 请求新数据
				const result = await getConfig()
				if (result) {
					// 存储完整的配置数据
					commit('SET_CONFIG', result)
					// 保存到本地存储
					uni.setStorageSync(STORAGE_KEY, JSON.stringify(result))
				}
				return result
			} catch (error) {
				console.error('获取配置失败：', error)
				throw error
			}
		},
		
		// 清除配置缓存
		clearConfigCache({ commit }) {
			try {
				uni.removeStorageSync(STORAGE_KEY)
				commit('SET_CONFIG', {
					icons: [],
					// 重置其他配置为默认值...
				})
				console.log('清理配置缓存成功')
			} catch (error) {
				console.error('清理配置缓存失败：', error)
				throw error
			}
		}
	},

})

export default store